@@ -59,6 +59,8 @@ class RoutingResult:
 		self.position = position
 		self.progress = progress
 
+	def __str__(self):
+		return 'RoutingResult(time=%s, path=%s, position=%s, progress=%f)' % (str(self.time), self.path, self.position, self.progress)
 
 class IsoPoint(NamedTuple):
 	pos: Tuple[float, float]
@@ -74,6 +76,9 @@ class IsoPoint(NamedTuple):
 	def toList(self):
 		return [self.pos[0], self.pos[1], self.prevIdx, self.time, self.twd, self.tws, self.speed, self.brg, self.nextWPDist, self.startWPLos]
 
+	def fromList(l):
+		return IsoPoint((l[0], l[1]), l[2], l[3], l[4], l[5], l[6], l[7], l[8], l[9])
+		
 	def lossodromic(self, to):
 		return utils.lossodromic (self.pos[0], self.pos[1], to[0], to[1])
 
@@ -118,7 +123,9 @@ class Router:
 		""" Calculate isochrones depending on routageSpeed from polar """
 		def pointF(p, tws, twa, dt, brg):
 			speed = self.polar.getSpeed (tws, math.copysign (twa,1))
-			return utils.routagePointDistance (p[0], p[1], speed * dt * utils.NAUTICAL_MILE_IN_KM, brg), speed
+			rpd = utils.routagePointDistance (p[0], p[1], speed * dt * utils.NAUTICAL_MILE_IN_KM, brg), speed
+			# print ('tws', tws, 'sog', speed, 'twa', math.degrees(twa), 'brg', math.degrees(brg), 'rpd', rpd)
+			return rpd
 
 		return self._calculateIsochrones(t, isocrone, nextwp, pointF)
 
@@ -175,6 +182,7 @@ class Router:
 
 			for twa in range(-180,180,5):
 				twa = math.radians(twa)
+				twd = math.radians(twd)
 				brg = utils.reduce360(twd + twa)
 
 				# Calculate next point
